==> ah-form-builder-sample-0.6.20.tgz: package/es/utils/selects/MultiSelect.js <==
var _jsxFileName = "/var/apps/ah-form-builder/src/utils/selects/MultiSelect.js";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import TextField from '@material-ui/core/TextField';
import Autocomplete from '@material-ui/lab/Autocomplete';
import Checkbox from "@material-ui/core/Checkbox";
import { makeStyles } from "@material-ui/core/styles";
var useStyles = makeStyles(function (theme) {
  return {
    labelRoot: {
      transform: 'none'
    }
  };
});
export default function MultiSelect(props) {
  var _this = this;

  var classes = useStyles();
  var options = props.options,
      value = props.value,
      handleChange = props.handleChange,
      label = props.label,
      error = props.error,
      required = props.required,
      placeholder = props.placeholder,
      helperText = props.helperText,
      disabled = props.disabled;
  var labelProp = props.labelProp ? props.labelProp : 'label';
  var valueProp = props.valueProp ? props.valueProp : 'value';
  var values = [];

  if (value.length) {
    options.map(function (option) {
      if (value.includes(option[valueProp])) {
        values.push(option);
      }
    });
  }

  return /*#__PURE__*/React.createElement(Autocomplete, {
    multiple: true,
    options: options,
    getOptionLabel: function getOptionLabel(option) {
      return option[labelProp];
    },
    value: values,
    disabled: disabled,
    disableCloseOnSelect: true,
    onChange: function onChange(event, newValue) {
      handleChange({
        target: {
          value: newValue.map(function (item) {
            return item[valueProp];
          })
        }
      });
    },
    renderOption: function renderOption(option) {
      return /*#__PURE__*/React.createElement(React.Fragment, {
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 39,
          columnNumber: 9
        }
      }, /*#__PURE__*/React.createElement(Checkbox, {
        checked: value.includes(option[valueProp]),
        color: "primary",
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 40,
          columnNumber: 11
        }
      }), option[labelProp]);
    },
    renderInput: function renderInput(params) {
      return /*#__PURE__*/React.createElement(TextField, _extends({}, params, {
        required: required,
        placeholder: value.length ? "" : placeholder,
        InputLabelProps: {
          shrink: true,
          classes: {
            shrink: classes.labelRoot
          }
        },
        label: label,
        error: !!error,
        helperText: error ? error : helperText ? helperText : null,
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 47,
          columnNumber: 30
        }
      }));
    },
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 28,
      columnNumber: 5
    }
  });
}

==> ah-form-builder-sample-0.6.85.tgz: package/es/utils/selects/MultiSelect.js <==
var _jsxFileName = "/var/www/html/formbuilder/src/utils/selects/MultiSelect.js";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import TextField from '@material-ui/core/TextField';
import Autocomplete from '@material-ui/lab/Autocomplete';
import Checkbox from "@material-ui/core/Checkbox";
import { makeStyles } from "@material-ui/core/styles";
var useStyles = makeStyles(function (theme) {
  return {
    labelRoot: {
      transform: 'none'
    }
  };
});
export default function MultiSelect(props) {
  var _this = this;

  var classes = useStyles();
  var options = props.options,
      value = props.value,
      handleChange = props.handleChange,
      label = props.label,
      error = props.error,
      required = props.required,
      placeholder = props.placeholder,
      helperText = props.helperText,
      disabled = props.disabled;
  var labelProp = props.labelProp ? props.labelProp : 'label';
  var valueProp = props.valueProp ? props.valueProp : 'value';
  var values = [];

  if (value.length) {
    options.map(function (option) {
      if (value.includes(option[valueProp])) {
        values.push(option);
      }
    });
  }

  return /*#__PURE__*/React.createElement(Autocomplete, {
    multiple: true,
    options: options,
    getOptionLabel: function getOptionLabel(option) {
      return option[labelProp];
    },
    value: values,
    disabled: disabled,
    disableCloseOnSelect: true,
    onChange: function onChange(event, newValue) {
      handleChange({
        target: {
          value: newValue.map(function (item) {
            return item[valueProp];
          })
        }
      });
    },
    renderOption: function renderOption(option) {
      return /*#__PURE__*/React.createElement(React.Fragment, {
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 39,
          columnNumber: 9
        }
      }, /*#__PURE__*/React.createElement(Checkbox, {
        checked: value && Array.isArray(value) && value.includes(option[valueProp]),
        color: "primary",
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 40,
          columnNumber: 11
        }
      }), option[labelProp]);
    },
    renderInput: function renderInput(params) {
      return /*#__PURE__*/React.createElement(TextField, _extends({}, params, {
        required: required,
        placeholder: value.length ? "" : placeholder,
        InputLabelProps: {
          shrink: true,
          classes: {
            shrink: classes.labelRoot
          }
        },
        label: label,
        error: !!error,
        helperText: error ? error : helperText ? helperText : null,
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 47,
          columnNumber: 30
        }
      }));
    },
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 28,
      columnNumber: 5
    }
  });
}
